Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8805)

Unified Diff: chrome/browser/ui/views/payments/payment_request_sheet_controller.h

Issue 2611253004: [Payment Request] Change the lifetime management of PaymentRequestImpl (Closed)
Patch Set: PaymentRequestImpl -> PaymentRequest Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/payment_request_sheet_controller.h
diff --git a/chrome/browser/ui/views/payments/payment_request_sheet_controller.h b/chrome/browser/ui/views/payments/payment_request_sheet_controller.h
index 332452f4f7fcef1d9ac422ae882f4980ca530a92..e2f3da6d4b314b3b54106fb93974fbb78655e1d7 100644
--- a/chrome/browser/ui/views/payments/payment_request_sheet_controller.h
+++ b/chrome/browser/ui/views/payments/payment_request_sheet_controller.h
@@ -17,7 +17,7 @@ class View;
namespace payments {
class PaymentRequestDialog;
-class PaymentRequestImpl;
+class PaymentRequest;
// The base class for objects responsible for the creation and event handling in
// views shown in the PaymentRequestDialog.
@@ -25,22 +25,21 @@ class PaymentRequestSheetController {
public:
// Objects of this class are owned by |dialog|, so it's a non-owned pointer
// that should be valid throughout this object's lifetime.
- // |impl| is also not owned by this and is guaranteed to outlive dialog.
- // Neither |impl| or |dialog| should be null.
- PaymentRequestSheetController(PaymentRequestImpl* impl,
+ // |request| is also not owned by this and is guaranteed to outlive dialog.
+ // Neither |request| or |dialog| should be null.
+ PaymentRequestSheetController(PaymentRequest* request,
PaymentRequestDialog* dialog)
- : impl_(impl),
- dialog_(dialog) {
- DCHECK(impl_);
+ : request_(request), dialog_(dialog) {
+ DCHECK(request_);
DCHECK(dialog_);
}
virtual ~PaymentRequestSheetController() {}
virtual std::unique_ptr<views::View> CreateView() = 0;
// The PaymentRequestImpl object associated with this instance of the dialog.
// Caller should not take ownership of the result.
- PaymentRequestImpl* impl() { return impl_; }
+ PaymentRequest* request() { return request_; }
// The dialog that contains and owns this object.
// Caller should not take ownership of the result.
@@ -48,7 +47,7 @@ class PaymentRequestSheetController {
private:
// Not owned. Will outlive this.
- PaymentRequestImpl* impl_;
+ PaymentRequest* request_;
// Not owned. Will outlive this.
PaymentRequestDialog* dialog_;
@@ -25,22 +25,21 @@ class PaymentRequestSheetController {
virtual ~PaymentRequestSheetController() {}
virtual std::unique_ptr<views::View> CreateView() = 0;
- // The PaymentRequestImpl object associated with this instance of the dialog.
+ // The PaymentRequest object associated with this instance of the dialog.
// Caller should not take ownership of the result.

Powered by Google App Engine
This is Rietveld 408576698